@@ -170,6 +170,7 @@ def PrLightPurple(skk):
 #--------------------------------
 
 @click.group()
+@click.pass_context
 def root():
     """Traslation of DocFX source code"""
     init()
@@ -198,7 +199,8 @@ def root():
     # option = input(' Digite uma opção:\n [1] para traduzir arquivos modificados desde o último commit,\n [2] para traduzir todo o projeto, ou\n [Enter] para sair: ')
 
     @root.command()
-    def diff():
+    @click.pass_context
+    def diff(workTree):
         if workTree:
             PrYellow('\n The following files will be added or overwritten in target languages:')
             for doc in workTree:
@@ -227,7 +229,7 @@ def root():
                                 os.remove(path + '/' + '/'.join(doc.split('/')[2:]))
                             except:
                                 pass
-                PrGreen('\n\n Completed succesfully!')
+                PrGreen('\n\n Completed successfully!')
         else:
             PrYellow('There are no changes since the last commit.')
         if cont != 'c': PrRed('\n\n Exiting...')
